SmartResponsiveContext extension

Extensions for BuildContext to get device type and screen size.

on

Properties

deviceType DeviceType

Available on BuildContext, provided by the SmartResponsiveContext extension

Returns the DeviceType based on the screen width.
no setter
isDesktop bool

Available on BuildContext, provided by the SmartResponsiveContext extension

Returns true if the device is a desktop device.
no setter
isMobile bool

Available on BuildContext, provided by the SmartResponsiveContext extension

Returns true if the device is a mobile device.
no setter
isTablet bool

Available on BuildContext, provided by the SmartResponsiveContext extension

Returns true if the device is a tablet device.
no setter