isDesktop property
bool
get
isDesktop
Returns true if the device is a desktop device.
Implementation
bool get isDesktop => deviceType == DeviceType.desktop;
Returns true if the device is a desktop device.
bool get isDesktop => deviceType == DeviceType.desktop;