SmartScreen class

A helper class to get screen properties.

Constructors

SmartScreen(BuildContext context)
Creates a SmartScreen instance.

Properties

context BuildContext
The build context.
final
hashCode int
The hash code for this object.
no setterinherited
height double
The screen height.
no setter
orientation Orientation
The screen orientation.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The screen width.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited